pub struct Event {
pub category: EventCategory,
pub operation: String,
pub source: ComponentId,
pub payload: Value,
}Expand description
An event that can be injected into a channel.
Events are the primary means of external input to a running channel. Unlike Signals (which are control messages), Events represent work to be processed by the bound Component.
Fields
category: EventCategoryCategory of this event (for routing).
operation: StringOperation to perform (maps to Component.on_request operation).
source: ComponentIdSource component that sent this event.
payload: ValueEvent payload data.