pub enum ApprovalResult {
Approved,
Rejected {
reason: Option<String>,
},
Modified {
modified_payload: Value,
},
}Expand description
Result of an approval request.
Variants
Approved
Request was approved by Human.
Rejected
Request was rejected by Human.
Modified
Request was approved with modifications by Human.
Implementations
Sourceimpl ApprovalResult
impl ApprovalResult
Sourcepub fn is_approved(&self) -> bool
pub fn is_approved(&self) -> bool
Returns true if the result is Approved or Modified.
Sourcepub fn is_rejected(&self) -> bool
pub fn is_rejected(&self) -> bool
Returns true if the result is Rejected.
Sourcepub fn is_modified(&self) -> bool
pub fn is_modified(&self) -> bool
Returns true if the result is Modified.
Sourcepub fn modified_payload(&self) -> Option<&Value>
pub fn modified_payload(&self) -> Option<&Value>
Returns the modified payload if this is a Modified result.